## How we the creators expect MiniIDE to behave in a few different scenarios

1. Typing in an expression involving constants into either the console (top
   line just below menu on screen) or Editor window evaluates it and prints
   the result in the console (above the bottom line on screen).

    ```
    > 1+1
    ```
    and press `Enter`.

    In editor:
    ```
    1+1
    ```
    and select 'Run' from the menu.

    Either way, you will see this below the console:
    ```
    > 1+1
    2
    ```

2. Typing in graphics involving constants into either the console or editor
   shows them on screen.

    ```
    > love.graphics.line(100,100, 200,300)
    ```

    You will see a line on the screen, potentially drawing over text in the
    console.

    Known issue: There are some slight differences in how your commands will
    render text compared to the console itself.
    ```
    > love.graphics.print('> love.graphics', 30,515)
    ```

    (These issues are quite subtle, so adjust the `515` above for your device
    to put the text next to the command that generated it.)

3. Typing in an expression involving variables into either the console or
   editor works as usual.

    ```
    > x = 1
    > x+1
    2
    ```

    In editor, type:
    ```
    x = 1
    ```
    and select 'Run'.

    Then clear editor and type:
    ```
    x+1
    ```
    and select 'Run' again.

    You can't put both statements into the editor at once. That would be like
    typing `x = 1; x+1` into the console or any Lua prompt. (Which also
    wouldn't work.)

4. You can draw multiple graphics in either console or editor.
    ```
    love.graphics.line(100,100, 200,300)
    love.graphics.line(100,20, 100,40)
    ```

    2 lines will appear.

5. You can change colors in either console or editor.
    ```
    > love.graphics.line(100,100, 200,100)
    > love.graphics.setColor(1,0,0)
    > love.graphics.line(100,120, 200,120)
    ```

    In editor:
    ```
    love.graphics.line(100,100, 200,300)
    love.graphics.setColor(1,0,0)
    love.graphics.line(100,120, 200,120)
    ```

    One of the lines will now be colored red.

6. For more complex graphics, override `love.draw`:
    ```
    lg = love.graphics

    function love.draw()
        lg.line(100,100, 200,300)
    end
    ```

    A line will appear.

    Once you select 'Run' you're running a whole new app, and you'll
    have no way to go back to MiniIDE. (intended behavior)

    This works in console if you define the function in a single line.
    ```
    > lg = love.graphics
    > function love.draw() lg.line(100,100, 200,300) end
    ```

    Blocks cannot continue across lines on the console.
    ```
    > function love.draw()
    ```
    Hitting enter now will result in an error.

    Try to keep function definitions in the editor.

7. To return to MiniIDE, override some standard LÖVE event to `escape()`:
    ```
    function love.draw()
        love.graphics.line(100,100, 200,300)
    end
    function love.keypressed(key)
        escape()
    end
    ```

    Now select "Append function to return to MiniIDE" from the menu.
    You will see some new code inserted into the editor so it looks like this:
    ```
    function love.draw()
        love.graphics.line(100,100, 200,300)
    end
    function love.keypressed(key)
        escape()
    end
    function escape()
        error('StopScript')
    end
    ```

    Now select 'Run' to see a new app draw a line across the whole screen.
    Press any key to return to MiniIDE.

8. You can also create an app that includes MiniIDE, like this:
    ```
    lg = love.graphics

    if old_love_draw == nil then
        old_love_draw = love.draw
    end

    function love.draw()
        old_love_draw()
        lg.line(100,100, 200,300)
    end
    ```

    This will look just like scenario 2 above, but it has more room to grow.
    You can take over other event handlers from MiniIDE like `love.keypressed`
    or `love.mousepressed`, and you can add rules before or after them. Any
    errors will put you back in MiniIDE without your app additions. For
    example, if you edit it to look like this:

    ```
    lg = love.graphics

    if old_love_draw == nil then
        old_love_draw = love.draw
    end

    function love.draw()
        old_love_draw()
        lg.line(100,100, 200,300)
    end

    function love.keypressed()
        print(y+1)  -- error: y is nil, and you can't add 1 to nil
    end
    ```

    Hit 'Run', then press a key. The key will have no effect, and you'll see
    an error like this in the log:
    ```
    Error: [string "lg = love.graphics..."]:13: attempt to perform arithmetic on global 'y' (a nil value)
    ```

    However, future keypresses (without selecting 'Run' again) will work. Your
    app has been 'deregistered', and things have gone back to pristine
    MiniIDE. Now you can fix the error and try selecting 'Run' again.

## More minor tests just as a checklist for testing

9. Tap on the console. A cursor will appear within. In a tablet the soft
   keyboard will pop up.

10. Select 'Load' from the menu. You will get a dialog with a dropdown. Select
    the dropdown. You'll be able to easily select files from the dropdown, and
    grab the scrollbar to scroll.

11. An empty editor window has no scrollbars.

12. Resize the editor window. You won't get a horizontal scrollbar, and all
    parts of it will be editable.
